@@ -1,4 +1,4 @@
-//@line 42 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/browser/base/content/pageInfo.js"
+//@line 42 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.ELsmp_Depend/mozilla/browser/base/content/pageInfo.js"
 
 //******** define a js object to implement nsITreeView
 function pageInfoTreeView(columnids, copycol)
@@ -182,8 +182,6 @@ const nsIEmbedElement    = Components.interfaces.nsIDOMHTMLEmbedElement
 const nsIButtonElement   = Components.interfaces.nsIDOMHTMLButtonElement
 const nsISelectElement   = Components.interfaces.nsIDOMHTMLSelectElement
 const nsITextareaElement = Components.interfaces.nsIDOMHTMLTextAreaElement
-const nsIQuoteElement    = Components.interfaces.nsIDOMHTMLQuoteElement
-const nsIModElement      = Components.interfaces.nsIDOMHTMLModElement
 
 // Interface for image loading content
 const nsIImageLoadingContent = Components.interfaces.nsIImageLoadingContent;
@@ -229,8 +227,6 @@ function onLoadPageInfo()
   gStrings.linkStylesheet = theBundle.getString("linkStylesheet");
   gStrings.linkRev = theBundle.getString("linkRev");
   gStrings.linkX = theBundle.getString("linkX");
-  gStrings.linkQuote = theBundle.getString("linkQuote");
-  gStrings.linkMod = theBundle.getString("linkMod");
   gStrings.mediaImg = theBundle.getString("mediaImg");
   gStrings.mediaBGImg = theBundle.getString("mediaBGImg");
   gStrings.mediaApplet = theBundle.getString("mediaApplet");
@@ -496,10 +492,6 @@ function grabAll(elem)
     addImage(elem.src, gStrings.mediaImg, (elem.hasAttribute("alt")) ? elem.alt : gStrings.notSet, elem, false);
   else if (elem instanceof nsIAreaElement)
     linkView.addRow([elem.alt, elem.href, gStrings.linkArea, elem.target]);
-  else if (elem instanceof nsIQuoteElement && elem.cite)
-    linkView.addRow([getValueText(elem), elem.cite, gStrings.linkQuote]);
-  else if (elem instanceof nsIModElement && elem.cite)
-    linkView.addRow([getValueText(elem), elem.cite, gStrings.linkMod]);
   else if (elem instanceof nsILinkElement)
   {
     if (elem.rel)
@@ -523,12 +515,9 @@ function grabAll(elem)
         addImage(elem.src, gStrings.mediaInput, (elem.hasAttribute("alt")) ? elem.alt : gStrings.notSet, elem, false);
         // Fall through, <input type="image"> submits, too
       case "submit":
-        // Form element properties can be hidden by child elements with the same name, so
-        // we need to use a special access method, XPCNativeWrapper, to get their real values
         if ("form" in elem && elem.form)
         {
-          var formWrapper = new XPCNativeWrapper(elem.form, "target", "action");
-          linkView.addRow([elem.value || getValueText(elem) || gStrings.linkSubmit, formWrapper.action, gStrings.linkSubmission, formWrapper.target]);
+          linkView.addRow([elem.value || getValueText(elem) || gStrings.linkSubmit, elem.form.action, gStrings.linkSubmission, elem.form.target]);
         }
         else
           linkView.addRow([elem.value || getValueText(elem) || gStrings.linkSubmit, '', gStrings.linkSubmission, '']);
@@ -536,8 +525,7 @@ function grabAll(elem)
   }
   else if (elem instanceof nsIFormElement)
   {
-    formWrapper = new XPCNativeWrapper(elem, "name", "method", "action");
-    formView.addRow([formWrapper.name, formWrapper.method, formWrapper.action, elem]);
+    formView.addRow([elem.name, elem.method, elem.action, elem]);
   }
   else if (elem instanceof nsIAppletElement)
   {
@@ -577,18 +565,16 @@ function onFormSelect()
     var clickedRow = formView.selection.currentIndex;
     // form-node;
     var form = formView.data[clickedRow][3];
-    const formWrapper = new XPCNativeWrapper(form,
-      "name", "elements", "encoding", "target", "getElementsByTagName()");
 
     var ft = null;
-    if (formWrapper.name)
-      ft = theBundle.getFormattedString("formTitle", [formWrapper.name]);
+    if (form.name)
+      ft = theBundle.getFormattedString("formTitle", [form.name]);
 
-    setItemValue("formenctype", formWrapper.encoding, theBundle.getString("default"));
-    setItemValue("formtarget", formWrapper.target, theBundle.getString("formDefaultTarget"));
+    setItemValue("formenctype", form.encoding, theBundle.getString("default"));
+    setItemValue("formtarget", form.target, theBundle.getString("formDefaultTarget"));
     document.getElementById("formname").value = ft || theBundle.getString("formUntitled");
 
-    var formfields = formWrapper.elements;
+    var formfields = form.elements;
 
     var length = formfields.length;
 
@@ -607,7 +593,7 @@ function onFormSelect()
       fieldView.addRow(["", elem.name, elem.type, val]);
     }
 
-    var labels = formWrapper.getElementsByTagName("label");
+    var labels = form.getElementsByTagName("label");
     var llength = labels.length;
     var label;
 
