@@ -426,22 +426,6 @@ function getLocale() {
   return gPref.getCharPref(PREF_GENERAL_USERAGENT_LOCALE);
 }
 
-/**
- * Read the update channel from defaults only.  We do this to ensure that
- * the channel is tightly coupled with the application and does not apply
- * to other instances of the application that may use the same profile.
- */
-function getUpdateChannel() {
-  var defaults =
-      gPref.QueryInterface(Components.interfaces.nsIPrefService).
-      getDefaultBranch(null);
-  try {
-    return defaults.getCharPref(PREF_APP_UPDATE_CHANNEL);
-  } catch (e) {
-    return "default";  // failover when pref not found
-  }
-}
-
 /**
  * An enumeration of items in a JS array.
  * @constructor
@@ -681,8 +665,6 @@ function Update(update) {
       this.isSecurityUpdate = attr.value == "true";
     else if (attr.name == "detailsURL")
       this._detailsURL = attr.value;
-    else if (attr.name == "channel")
-      this.channel = attr.value;
     else
       this[attr.name] = attr.value;
   }
@@ -788,7 +770,6 @@ Update.prototype = {
     update.setAttribute("statusText", this.statusText);
     update.setAttribute("buildID", this.buildID);
     update.setAttribute("isCompleteUpdate", this.isCompleteUpdate);
-    update.setAttribute("channel", this.channel);
     updates.documentElement.appendChild(update);
     
     for (var p in this._properties) {
@@ -982,7 +963,10 @@ UpdateService.prototype = {
       var shouldCleanup = true;
       var update = um.activeUpdate;
       if (!update) {
-        update = new Update(null);
+        if ((status == STATE_SUCCEEDED) && (um.updateCount >= 1))
+          update = um.getUpdateAt(0);
+        else
+          update = new Update(null);
       }
       update.state = status;
       var sbs = 
@@ -1488,7 +1472,7 @@ UpdateManager.prototype = {
    */
   get activeUpdate() {
     if (this._activeUpdate &&
-        this._activeUpdate.channel != getUpdateChannel()) {
+        this._activeUpdate.serviceURL != Checker.prototype.updateURL) {
       // User switched channels, clear out any old active updates and remove
       // partial downloads
       this._activeUpdate = null;
@@ -1688,6 +1672,17 @@ Checker.prototype = {
       return null;
     }
 
+    // Read the update channel from defaults only.  We do this to ensure that
+    // the channel is tightly coupled with the application and does not apply
+    // to other instances of the application that may use the same profile.
+    function getUpdateChannel() {
+      try {
+        return defaults.getCharPref(PREF_APP_UPDATE_CHANNEL);
+      } catch (e) {
+        return "default";  // failover when pref not found
+      }
+    }
+
     url = url.replace(/%PRODUCT%/g, gApp.name);
     url = url.replace(/%VERSION%/g, gApp.version);
     url = url.replace(/%BUILD_ID%/g, gApp.appBuildID);
@@ -1764,7 +1759,6 @@ Checker.prototype = {
       updateElement.QueryInterface(Components.interfaces.nsIDOMElement);
       var update = new Update(updateElement);
       update.serviceURL = this.updateURL;
-      update.channel = getUpdateChannel();
       updates.push(update);
     }
 
@@ -2478,7 +2472,7 @@ TimerManager.prototype = {
   }
 };
 
-//@line 2482 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2476 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
 /**
  * UpdatePrompt
  * An object which can prompt the user with information about updates, request
@@ -2620,7 +2614,7 @@ UpdatePrompt.prototype = {
     return this;
   }
 };
-//@line 2624 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2618 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
 
 var gModule = {
   registerSelf: function(componentManager, fileSpec, location, type) {
@@ -2672,13 +2666,13 @@ var gModule = {
                className  : "Update Checker",
                factory    : #1#(Checker)
              },
-//@line 2676 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2670 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
     prompt:  { CID        : Components.ID("{27ABA825-35B5-4018-9FDD-F99250A0E722}"),
                contractID : "@mozilla.org/updates/update-prompt;1",
                className  : "Update Prompt",
                factory    : #1#(UpdatePrompt)
              },
-//@line 2682 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2676 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
     timers:  { CID        : Components.ID("{B322A5C0-A419-484E-96BA-D7182163899F}"),
                contractID : "@mozilla.org/updates/timer-manager;1",
                className  : "Timer Manager",
@@ -2709,14 +2703,14 @@ function NSGetModule(compMgr, fileSpec) {
  *          the specified update, false otherwise.
  */
 function isCompatible(update) {
-//@line 2713 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2707 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
   var em = 
       Components.classes["@mozilla.org/extensions/manager;1"].
       getService(Components.interfaces.nsIExtensionManager);
   var items = em.getIncompatibleItemList("", update.extensionVersion,
     nsIUpdateItem.TYPE_ADDON, false, { });
   return items.length == 0;
-//@line 2722 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2716 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
 }
 
 /**
@@ -2735,7 +2729,7 @@ function showPromptIfNoIncompatibilities(update) {
     prompter.showUpdateAvailable(update);
   }
 
-//@line 2741 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2735 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
   /**
    * Determines if an addon is compatible with a particular update.
    * @param   addon
@@ -2835,6 +2829,6 @@ function showPromptIfNoIncompatibilities(update) {
     em.update([], 0, mode != 0, listener);
   }
   else
-//@line 2841 "/builds/tinderbox/Fx-Mozilla1.8/Linux_2.4.21-27.0.4.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
+//@line 2835 "/builds/tinderbox/Fx-Mozilla1.8.0/Linux_2.4.21-37.ELsmp_Depend/mozilla/toolkit/mozapps/update/src/nsUpdateService.js.in"
     showPrompt(update);
 }
